import { Component, ViewChild, Inject } from "@angular/core";

import * as wijmo from "wijmo/wijmo";
import * as input from "wijmo/wijmo.input";
import * as wjChart from "wijmo/wijmo.chart";
import * as interaction from "wijmo/wijmo.chart.interaction";

import { DataService } from './app.data';
import { AggregateSeries } from './aggregate-series';

@Component({
  selector: "app-root",
  templateUrl: "./app.component.html",
  styleUrls: ["./app.component.css"],
  providers: [DataService]
})
export class AppComponent {
  @ViewChild("chart", { static: true}) chart: wjChart.FlexChart;
  data: any;
  palette = [
    "rgba(55,90,127,1)",
    "rgba(0,188,140,1)",
    "rgba(52,152,219,1)",
    "rgba(243,156,18,1)",
    "rgba(231,76,60,1)",
    "rgba(143,97,179,1)",
    "rgba(176,135,37,1)",
    "rgba(74,73,73,1)",
    "rgba(0,0,0,1)"
  ];
  series: AggregateSeries;
  groupAggregate = "Sum";
  //
  constructor(private dataService: DataService) {
    this.data = dataService.getData();
  }
  //
  rangeChanged(sender: interaction.RangeSelector, chart: wjChart.FlexChart) {
    chart.axisX.min = sender.min;
    chart.axisX.max = sender.max;
  }
  //
  ngAfterViewInit() {
    this.series = new AggregateSeries();
    this.chart.beginUpdate();
    this.series.itemsSource = this.dataService.getData();
    this.series.chartType = wjChart.ChartType.LineSymbols;
    this.series.binding = "close";
    this.series.bindingX = "date";
    this.series.groupAggregate = <any>this.groupAggregate;
    this.series.autoGroupIntervals = ["DD", "WW", "MM", "YYYY"];
    this.series.autoInterval = true;
    this.chart.series.push(this.series);
    this.chart.endUpdate();
  }
  //
  getTooltipContent(ht: wjChart.HitTestInfo) {
    return ht && ht.x && ht.y
      ? `<b>Date:</b> ${wijmo.Globalize.formatDate(
          ht.x,
          "MM-dd-yyyy"
        )}<br><b>Value:</b> ${ht.y.toFixed(2)}`
      : "";
  }
  //
  onMenuItemClick(menu: input.Menu) {
    this.series.groupAggregate = menu.selectedValue;
  }
}
